/**************************************************************************/ /**
																			  * @item     CosyOS-II Hook
																			  * @file     init_hook.c
																			  * @brief    初始化钩子
																			  * @detail   在主函数中首先被调用，适用于初始化时钟、GPIO、寄存器等工作。
																			  * @author   迟凯峰
																			  * @version  V2.0.0
																			  * @date     2024.03.17
																			  ******************************************************************************/

#include "..\System\os_link.h"
#include "..\Test\test.h"
#include "CosyOS.h"
#include "STC32G_GPIO.h"
#include "STC32G_DMA.h"
#include "STC32G_ADC.h"
#include "STC32G_Exti.h"
#include "STC32G_I2C.h"
#include "STC32G_SPI.h"
#include "STC32G_Timer.h"
#include "STC32G_UART.h"
#include "STC32G_Compare.h"
#include "STC32G_Delay.h"
#include "STC32G_Switch.h"
#include "STC32G_WDT.h"
#include "STC32G_NVIC.h"

/*
 * 默认配置：
 * 1、TASK_0中的printf，用串口1
 * 2、任务管理器，用串口2
 * 3、串口1、串口2，共用定时器2做波特率发生器
 * 4、串口1切换至P1.6/P1.7，串口2不切换
 * 5、PendSV_Handler，用INT0中断，中断优先级必须为最低级
 * 6、中断服务测试，会用到定时器1、定时器1中断、INT1中断、ADC中断
 *
 * 用户可根据自身情况重新调整串口
 */
void init_meature_task(void);
void init_hook(void)
{

	WTST = 0;  // 设置程序指令延时参数，赋值为0可将CPU执行指令的速度设置为最快
	EAXFR = 1; // 扩展寄存器(XFR)访问使能
	CKCON = 0; // 提高访问XRAM速度

	////P0_MODE_IO_PU(GPIO_Pin_All);		//P0 设置为准双向口
	P1_MODE_IO_PU(GPIO_Pin_All); // P1 设置为准双向口
	P2_MODE_IO_PU(GPIO_Pin_All); // P2 设置为准双向口
								 // P3_MODE_IO_PU(GPIO_Pin_All); //P3 设置为准双向口
								 ////P4_MODE_IO_PU(GPIO_Pin_All);		//P4 设置为准双向口
								 ////P5_MODE_IO_PU(GPIO_Pin_All);		//P5 设置为准双向口
								 ////P6_MODE_IO_PU(GPIO_Pin_All);		//P6 设置为准双向口
								 ////P7_MODE_IO_PU(GPIO_Pin_All);		//P7 设置为准双向口

	/* printf */
	/* UART1中断优先级为3级 */
	// COMx_InitStructure.UART_Mode = UART_8bit_BRTx;	// 模式, UART_ShiftRight,UART_8bit_BRTx,UART_9bit,UART_9bit_BRTx
	// COMx_InitStructure.UART_BRT_Use = BRT_Timer2;	// 选择波特率发生器, BRT_Timer1, BRT_Timer2 (注意: 串口2固定使用BRT_Timer2)
	// COMx_InitStructure.UART_BaudRate = 115200ul;	// 波特率, 一般 110 ~ 115200
	// COMx_InitStructure.UART_RxEnable = DISABLE;		// 接收允许,   ENABLE或DISABLE
	// COMx_InitStructure.BaudRateDouble = DISABLE;	// 波特率加倍, ENABLE或DISABLE
	// UART_Configuration(UART1, &COMx_InitStructure); // 初始化串口1 UART1,UART2,UART3,UART4
	// NVIC_UART1_Init(ENABLE, Priority_3);			// 中断使能, ENABLE/DISABLE; 优先级(低到高) Priority_0,Priority_1,Priority_2,Priority_3
	// UART1_SW(UART1_SW_P16_P17);						// UART1_SW_P30_P31,UART1_SW_P36_P37,UART1_SW_P16_P17,UART1_SW_P43_P44

/* 任务管理器 */
#if SYSCFG_DEBUGGING == 1
	{
		COMx_InitDefine COMx_InitStructure; // 结构定义

		/* UART1中断优先级为3级 */
		COMx_InitStructure.UART_Mode = UART_8bit_BRTx;	// 模式,   UART_ShiftRight,UART_8bit_BRTx,UART_9bit,UART_9bit_BRTx
		COMx_InitStructure.UART_BRT_Use = BRT_Timer2;	// 选择波特率发生器, BRT_Timer2 (注意: 串口2固定使用BRT_Timer2, 所以不用选择)
		COMx_InitStructure.UART_BaudRate = 115200ul;	// 波特率,     110 ~ 115200
		COMx_InitStructure.UART_RxEnable = ENABLE;		// 接收允许,   ENABLE或DISABLE
		COMx_InitStructure.BaudRateDouble = DISABLE;	// 波特率加倍, ENABLE或DISABLE
		UART_Configuration(UART1, &COMx_InitStructure); // 初始化串口1 UART1,UART2,UART3,UART4
		NVIC_UART1_Init(ENABLE, Priority_3);			// 中断使能, ENABLE/DISABLE; 优先级(低到高) Priority_0,Priority_1,Priority_2,Priority_3
		UART1_SW(UART1_SW_P30_P31);
		P3_MODE_IO_PU(GPIO_Pin_0 | GPIO_Pin_1);
	}
#endif

	{
		/* PendSV_Handler */
		/* P7 中断优先级为0级 */
		P7_MODE_IO_PU(GPIO_Pin_All);
		PIN_IPH = 0x00;
		PIN_IP = 0x00;
		/* P07 中断模式，下降沿 */
		P7IM0 = 0x00;
		P7IM1 = 0x00;
		/* 设置高电平，下降沿触发 */
		P70 = 1;
	}

	// LED 亮灯
	P22 = 0;
	init_meature_task();
}

#if SYSCFG_DEBUGGING == 1
/*
 * UART1中断（中断优先级为3级，using bank3）
 */
void UART1_Isr(void) interrupt UART1_VECTOR
{
	if (TI)
	{
		TI = 0;
		if (*s_debug_sendptr)
		{
			SBUF = *s_debug_sendptr++;
		}
		else
		{
			iDebugSend;
		}
	}
	if (RI)
	{
		RI = 0;
		if (s_debug_recvptr - s_debug_recvbuff < OS_DEBUGRECVBUFFSIZE - 1)
		{
			*s_debug_recvptr++ = SBUF;
		}
		iDebugRecv;
	}
}
#endif
